@@ -76,7 +76,7 @@ def dataflow_from_proto(client: Client, data_service_id: str, proto: api_pb2.Dat
                             input_dataflow_id=df.project.id if df.project.id else df.prj_id,
                             input_data_feed_id=df.id))
     elif c.type == "group":
-      component_ids = sorted([uuid_map[input.uuid] for input in c.content])
+      component_ids = sorted([uuid_map[input.uuid] for input in c.content if input.uuid in uuid_map])
       groups.append(ComponentGroup(id=c.id, name=c.name, description=c.description, component_ids=component_ids))
 
   return Dataflow(
